<?php
// $Id: pnadminapi.php,v 1.12 2003/05/15 15:55:30 garubi Exp $
// ----------------------------------------------------------------------
// POST-NUKE Content Management System
// Copyright (C) 2001 by the PostNuke Development Team.
// http://www.postnuke.com/
// ----------------------------------------------------------------------
// Based on:
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
// Original Author of file: Stefano Garuti
// Purpose of file:  concert administration API
// ----------------------------------------------------------------------

/**
 * create a new concert item
 *
 * Creates a new db row with concert data;
 * Automatically adds user_id and modify date  
 *
 * @param $args['dc_data'] (required) concert date format: yyyy-mm-dd
 * @param $args['dc_paese'] (required) concert location
 * @param $args['dc_prov'] state or province
 * @param $args['dc_stato'] nation
 * @param $args['dc_locale'] where the concert is, ie: Danny's pub, Concert Hal, ecc 
 * @param $args['dc_note']  annotations
 * @param $args['dc_infomailnome1'] name of the first email contact
 * @param $args['dc_infomailaddr1'] email address of the first email contact
 * @param $args['dc_infotelnome1'] name of the first telephone contact
 * @param $args['dc_infotel1'] telephone number of the first telephone contact
 * @param $args['dc_infotelnome2'] name of the second telephone contact
 * @param $args['dc_infotel2'] telephone number of the second telephone contact
 * @param $args['dc_url_locale'] concert web page url
 * @param $args['dc_indirizzo_locale'] concert address
 * @param $args['dc_conf'] concert status: 0: confirmed, 1: not confirmed, 2: canceled, 3: sold out
 * @param $args['dc_category'] concert category: 0: public, 1: reserved
 * @returns int
 * @return concert item ID on success, false on failure
 */
function concert_adminapi_create($args)
{
    // Get arguments from argument array
    extract($args);
	
    // Argument check
    if ((!isset($dc_paese)) ||
        (!isset($dc_data))) {
        pnSessionSetVar('errormsg', _CONCARGSERROR);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'concert::', '::', ACCESS_MODERATE)) {
        pnSessionSetVar('errormsg', _CONCNOAUTH);
        return false;
    }
    if (!pnSecAuthAction(0, 'concert::', '::', ACCESS_ADD)) {
			  // the user haven't ADD permission: the new concert is queued for
				// approvation
				$dc_approved = 0;
						}
		else {
				 // if the user has ADD permission we set the new concert as
				 // already approved
				$dc_approved = 1;						 
		}
		
	/**
	* crea il dc_user per tenere traccia di chi crea e modifica concerti
	* inserisce la data di creazione o di modifica direttamente nella query sql
	*/
	$dc_user = pnUserGetVar('uid');
	$dc_submitter = pnUserGetVar('uid');
	
    // Get datbase setup
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

    // Get next ID in table
    $nexdc_id = $dbconn->GenId($concerttable);
    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _CREATEFAILED);
        return false;
    }

    // Add item
    $sql = "INSERT INTO $concerttable (
              $concertcolumn[dc_id], 
$concertcolumn[dc_paese], 
$concertcolumn[dc_prov], 
$concertcolumn[dc_stato], 
$concertcolumn[dc_locale], 
$concertcolumn[dc_note], 
$concertcolumn[dc_infomailnome1], 
$concertcolumn[dc_infomailaddr1], 
$concertcolumn[dc_infotelnome1], 
$concertcolumn[dc_infotel1], 
$concertcolumn[dc_infotelnome2], 
$concertcolumn[dc_infotel2], 
$concertcolumn[dc_url_locale], 
$concertcolumn[dc_indirizzo_locale],
$concertcolumn[dc_data], 
$concertcolumn[dc_conf], 
$concertcolumn[dc_user], 
$concertcolumn[dc_data_modif], 
$concertcolumn[dc_category],
$concertcolumn[dc_lang],
$concertcolumn[dc_approved],
$concertcolumn[dc_submitter] 
			  )
            VALUES (
              $nexdc_id,
			  '" . pnvarPrepForStore($dc_paese) . "',
			  '" . pnvarPrepForStore($dc_prov) . "',			  
			  '" . pnvarPrepForStore($dc_stato) . "',			  
			  '" . pnvarPrepForStore($dc_locale) . "',			  
			  '" . pnvarPrepForStore($dc_note) . "',			  
			  '" . pnvarPrepForStore($dc_infomailnome1) . "',			  
			  '" . pnvarPrepForStore($dc_infomailaddr1) . "',			  
			  '" . pnvarPrepForStore($dc_infotelnome1) . "',			  
			  '" . pnvarPrepForStore($dc_infotel1) . "',			  
			  '" . pnvarPrepForStore($dc_infotelnome2) . "',			  
			  '" . pnvarPrepForStore($dc_infotel2) . "',			  
			  '" . pnvarPrepForStore($dc_url_locale) . "',			  
			  '" . pnvarPrepForStore($dc_indirizzo_locale) . "',			  
              '" . pnVarPrepForStore($dc_data) . "',
              '" . pnVarPrepForStore($dc_conf) . "',
			  '" . pnVarPrepForStore($dc_user) . "',
 			  NOW(),
			  '" . pnVarPrepForStore($dc_category) . "',
              '" . pnVarPrepForStore($dc_lang) . "',
							'".pnVarPrepForStore($dc_approved) . "',
							'".pnVarPrepForStore($dc_submitter) . "')";
			  
    $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', '<br />-->pnadminapi create<-- '._CREATEFAILED);
        return false;
    }

    // Get dc_id to return
    $dc_id = $dbconn->PO_Insert_ID($concerttable, $concertcolumn['dc_id']);
    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', 'anche qui '._CREATEFAILED);
        return false;
    }
    // Hooks
    if (pnSecAuthAction(0, 'concert::', '::', ACCESS_ADD)) {
		    pnModCallHooks('item', 'create', $dc_id, '');
		}

   // If the concert is only queued, ie is waiting for approvation,
   // we can notify the admin with an email
   if ($dc_approved==0 && $email=pnModGetVar('concert', 'email')) {
      // DEBUG
      //print "<pre>we are sending an email to $email</pre>";
      $subject = _CONCERTNOTIFYSUBJ;
      $message = _CONCERTNOTIFYMESSAGE.'\n';
      $message.= _CONCERTNOTIFYAPPROVE.' '.pnModURL('concert', 'admin', 'viewpending').'\n';
      $headers = 'from: '.pnConfigGetVar('sitename');
      pnMail($email, $subject, $message, $headers);
   }
    return $dc_id;
}

/**
 * delete a concert item
 *
 * @param array $args['dc_id'] (required) ID of the concert to delete
 * @return bool
 * @return true on success, false on failure
 */
function concert_adminapi_delete($args)
{
    // Get arguments from argument array - all arguments to this function
    // should be obtained from the $args array, getting them from other
    // places such as the environment is not allowed, as that makes
    // assumptions that will not hold in future versions of PostNuke
    extract($args);

    // Argument check - make sure that all required arguments are present,
    // if not then set an appropriate error message and return
    if (!isset($dc_id)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Load API.  Note that this is loading the user API in addition to
    // the administration API, that is because the user API contains
    // the function to obtain item information which is the first thing
    // that we need to do.  If the API fails to load an appropriate error
    // message is posted and the function returns
    if (!pnModAPILoad('concert', 'user')) {
        pnSessionSetVar('errormsg',_LOADFAILED);
        return false;
    }

    // The user API function is called.  This takes the item ID which
    // we obtained from the input and gets us the information on the
    // appropriate item.  If the item does not exist we post an appropriate
    // message and return
    $item = pnModAPIFunc('concert',
            'user',
            'get',
            array('dc_id' => $dc_id));

    if ($item == false) {
        pnSessionSetVar('errormsg', _CONCERTNOSUCHITEM);
        return false;
    }

    // Security check - important to do this as early on as possible to 
    // avoid potential security holes or just too much wasted processing.
    // However, in this case we had to wait until we could obtain the item
    // name to complete the instance information so this is the first
    // chance we get to do the check
    if (!pnSecAuthAction(0, 'concert::', "$item[dc_category]::$dc_id", ACCESS_DELETE)) {
        pnSessionSetVar('errormsg', _CONCERTNOAUTH);
        return false;
    }

    // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn()
    // we currently just want the first item, which is the official
    // database handle.  For pnDBGetTables() we want to keep the entire
    // tables array together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you
    // are getting - $table and $column don't cut it in more complex
    // modules
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

    // Delete the item - the formatting here is not mandatory, but it does
    // make the SQL statement relatively easy to read.  Also, separating
    // out the sql statement from the Execute() command allows for simpler
    // debug operation if it is ever needed
    $sql = "DELETE FROM $concerttable
            WHERE $concertcolumn[dc_id] = " . pnVarPrepForStore($dc_id);
    $dbconn->Execute($sql);

    // Check for an error with the database code, and if so set an
    // appropriate error message and return
    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _DELETEFAILED);
        return false;
    }

    // Let any hooks know that we have deleted an item.  As this is a
    // delete hook we're not passing any extra info
    pnModCallHooks('item', 'delete', $dc_id, '');

    // Let the calling process know that we have finished successfully
    return true;
}


/**
 * update a concert item
 *
 * take the concert id and other concert data (date and location are required)
 * and update the corresponding db row
 * 
 * @param $args['dc_id'] (required) the ID of the concert
 * @param $args['dc_paese'] (require) the concert location
 * @param $args['dc_data'] (required) the concert date
 * @see concert_adminapi_create() for other optional arguments
 * @return true on succes
 * @return false on failure
 */
function concert_adminapi_update($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if ((!isset($dc_id)) ||
        (!isset($dc_paese)) ||
		(!isset($dc_data))) {
        pnSessionSetVar('errormsg', _MODARGSERROR. ' update API');
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'concert::', "::", ACCESS_EDIT)) {
        pnSessionSetVar('errormsg', _CONCERTNOAUTH);
        return false;
    }

    // Security check
    if (!pnSecAuthAction(0, 'concert::', "::", ACCESS_ADD) && $dc_approved==1) {
        pnSessionSetVar('errormsg', _CONCERTNOAUTH.' update func. approve');
        return false;
    }
	
    // Get database setup
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

	/**
	* crea il dc_user per tenere traccia di chi crea e modifica concerti
	* inserisce la data di creazione o di modifica direttamente nella query sql
	*/
	$dc_user = pnUserGetVar('uid');

    // Update the item
    $sql = "UPDATE $concerttable
            SET 
			$concertcolumn[dc_paese] = '" . pnVarPrepForStore($dc_paese) . "', 
$concertcolumn[dc_prov] = '" . pnVarPrepForStore($dc_prov) . "', 
$concertcolumn[dc_stato] = '" . pnVarPrepForStore($dc_stato) . "', 
$concertcolumn[dc_locale] = '" . pnVarPrepForStore($dc_locale) . "', 
$concertcolumn[dc_note] = '" . pnVarPrepForStore($dc_note) . "', 
$concertcolumn[dc_infomailnome1] = '" . pnVarPrepForStore($dc_infomailnome1) . "', 
$concertcolumn[dc_infomailaddr1] = '" . pnVarPrepForStore($dc_infomailaddr1) . "', 
$concertcolumn[dc_infotelnome1] = '" . pnVarPrepForStore($dc_infotelnome1) . "', 
$concertcolumn[dc_infotel1] = '" . pnVarPrepForStore($dc_infotel1) . "', 
$concertcolumn[dc_infotelnome2] = '" . pnVarPrepForStore($dc_infotelnome2) . "', 
$concertcolumn[dc_infotel2] = '" . pnVarPrepForStore($dc_infotel2) . "', 
$concertcolumn[dc_url_locale] = '" . pnVarPrepForStore($dc_url_locale) . "', 
$concertcolumn[dc_indirizzo_locale] = '" . pnVarPrepForStore($dc_indirizzo_locale) . "',
$concertcolumn[dc_data] = '" . pnVarPrepForStore($dc_data) . "', 
$concertcolumn[dc_conf] = '" . pnVarPrepForStore($dc_conf) . "', 
$concertcolumn[dc_user] = '" . pnVarPrepForStore($dc_user) . "', 
$concertcolumn[dc_data_modif] = NOW(), 
$concertcolumn[dc_category] = '" . pnVarPrepForStore($dc_category) . "',
$concertcolumn[dc_lang] = '" . pnVarPrepForStore($dc_lang) . "',
$concertcolumn[dc_approved] = '" . pnVarPrepForStore($dc_approved) . "',
$concertcolumn[dc_submitter] = '" . pnVarPrepForStore($dc_submitter) . 
"' WHERE $concertcolumn[dc_id] = " . pnVarPrepForStore($dc_id);
    						 // DEBUG
						 //echo '<pre>';
						 //$dbconn->debug = true;
	$dbconn->Execute($sql);
							 //echo '</pre>';
    if ($dbconn->ErrorNo() != 0) {
        pnSessionSetVar('errormsg', _UPDATEFAILED);
        return false;
    }

    // Hooks
    pnModCallHooks('item', 'update', $dc_id, '');

    return true;
}

/**
* Get year, month, day from a concert date
*
* Parse and Explode a given date (in concert standard format i.e. yyyy-mm-dd
* and return an associative array of month, year and day
* and formatted dates according to MultiLanguage settings
* 
* @param string $data the formatted string in the form of yyyy-mm-dd
* @return array $item['day'], $item['month'], $item['year']: the single day, month, year values 
* @return array $item['datelong'], $item['dateshort'], $item['datecompact']: formatted according to language defines
* @return false on failure
*/
function concert_adminapi_expdate ($data)
{
	// Argument check
    if (!isset($data)) {
        pnSessionSetVar('errormsg', _MODARGSERROR. 'in function date explode');
        return false;
    }
	$item = array();
	$item['year']=substr($data,0,4);
    $item['month']=substr($data,5,2);
    $item['day']=substr($data,8,2);
	$item['datelong']= ml_ftime(_CONCERTDATELONG, strtotime($data));
	$item['dateshort']= ml_ftime(_CONCERTDATESHORT, strtotime($data));
	$item['datecompact']= ml_ftime(_CONCERTDATECOMPACT, strtotime($data)); 
	return $item;
}

/**
* Format a concert date to store it
*
* Implode a given year, month, day in a concert standard formatted date
* ready to be stored in database...
* 
* @param $args['dc_year'] concert year
* @param $args['dc_month'] concert month
* @param $args['dc_day'] concert day
* @return string the formatted date: yyyy-mm-dd
* @return false on failure
*/
function concert_adminapi_impdate ($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if ((!isset($dc_year)) ||
        (!isset($dc_month)) ||
        (!isset($dc_day))) {
        pnSessionSetVar('errormsg', _MODARGSERROR. ' in function date implode');
        return false;
    }
	
	// Check for a valid date
	if(!checkdate($dc_month, $dc_day, $dc_year)){
		pnSessionSetVar('errormsg', _DATE_ERROR);
        return false;
	}
	
	
	$dc_data= sprintf ("%04d-%02d-%02d", $dc_year, $dc_month, $dc_day);
	
	return $dc_data;
}
/**
 * get concert items pending approvation
 * 
 * @param $args['startnum'] first item number (for pager function)
 * @param $args['numitems'] how many items (for pager function)
 * @return array of items, or false on failure
 */
function concert_adminapi_getpending($args)
{
    //
    extract($args);

    // Optional arguments.
    if (!isset($startnum)) {
        $startnum = 1;
    }
    if (!isset($numitems)) {
        $numitems = -1;
    }
	
    if ((!isset($startnum)) ||
        (!isset($numitems))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }
		
	$items = array();

    // Security check
    if (!pnSecAuthAction(0, 'concert::', '::', ACCESS_ADD)) {
        return $items;
    }

    // Database information
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

	
		// Get items
    $sql = 	"SELECT * FROM $concerttable WHERE $concertcolumn[dc_approved]='0' ORDER BY $concertcolumn[dc_data]";

    $result = $dbconn->Execute($sql);

	
	
    if ($dbconn->ErrorNo() != 0) {
        return false;
    }

    // Put items into result array
    for (; !$result->EOF; $result->MoveNext()) {
        list(	$dc_id,
				$dc_paese,
				$dc_prov,
				$dc_stato,
				$dc_locale,
				$dc_note,
				$dc_infomailnome1,
				$dc_infomailaddr1,
				$dc_infotel1,
				$dc_infotel2,
				$dc_url_locale,
				$dc_indirizzo_locale,
				$dc_n_comm,
				$dc_data,
				$dc_conf,
				$dc_user,
				$dc_data_modif,
				$dc_category,
				$dc_lang,
				$dc_infotelnome1,
				$dc_infotelnome2,
				$dc_approved,
				$dc_submitter
			) = $result->fields;

// we''ll need to enable this security check when we'll support different groups/artists
        //if (pnSecAuthAction(0, 'concert::GROUPS', "::", ACCESS_OVERVIEW)) {
            $items[] = array('dc_id' => $dc_id,
							 'dc_paese' => $dc_paese,
							 'dc_prov' => $dc_prov,
							 'dc_stato' => $dc_stato,
							 'dc_locale' => $dc_locale,
							 'dc_note' => $dc_note,
							 'dc_infomailnome1' => $dc_infomailnome1,
							 'dc_infomailaddr1' => $dc_infomailaddr1,
							 'dc_infotel1' => $dc_infotel1,
							 'dc_infotel2' => $dc_infotel2,
							 'dc_url_locale' => $dc_url_locale,
							 'dc_indirizzo_locale' => $dc_indirizzo_locale,
							 'dc_n_comm' => $dc_n_comm,
							 'dc_data' => $dc_data,
							 'dc_conf' => $dc_conf,
							 'dc_user' => $dc_user,
							 'dc_data_modif' => $dc_data_modif,
							 'dc_category' => $dc_category,
							 'dc_lang' => $dc_lang,
							 'dc_infotelnome1' => $dc_infotelnome1,
							 'dc_infotelnome2' => $dc_infotelnome2,
							 'dc_approved' => $dc_approved,
							 'dc_submitter' => $dc_submitter);
       // }
    }
    $result->Close();

		// we can't use SelectLimit because we need to consider the more GROUPS!
		// so we slice here the result array to do the paging 
		$sliced=array_slice($items,$startnum-1,$numitems);
		return $sliced;
    //return $items;
}

/**
 * utility function to count the number of pending concert 
 * 
 * @return integer number of pending items
 */
function concert_adminapi_countpending()
{
    // Get database setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn() we
    // currently just want the first item, which is the official database
    // handle.  For pnDBGetTables() we want to keep the entire tables array
    // together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you are
    // getting - $table and $column don't cut it in more complex modules
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

    $sql = "SELECT COUNT(1) FROM $concerttable WHERE ".$concertcolumn['dc_approved']."='0'";

		$result = $dbconn->Execute($sql);

		
    // Check for an error with the database code, and if so set an appropriate
    // error message and return
    if ($dbconn->ErrorNo() != 0) {
        return false;
    }

    // Obtain the number of items
    list($numitems) = $result->fields;

    // All successful database queries produce a result set, and that result
    // set should be closed when it has been finished with
    $result->Close();

    // Return the number of items
    return $numitems;
}

/**
 * utility function to set the defaults value for each field in add/submit view
 *
 * @return associative array of fileds=>default values 
 */
function concert_adminapi_defaults ()
{
	return $item = array('dc_id' => '',
							 	 			 'dc_paese' => '',
											 'dc_prov' => '',
							 				 'dc_stato' => '',
							 				 'dc_locale' => '',
							 				 'dc_note' => '',
							 				 'dc_infomailnome1' => '',
							 				 'dc_infomailaddr1' => '',
							 				 'dc_infotel1' => '',
							 				 'dc_infotel2' => '',
							 				 'dc_url_locale' => '',
							 				 'dc_indirizzo_locale' => '',
							 				 'dc_n_comm' => '',
							 				 'dc_data' => '',
							 				 'dc_conf' => '',
							 				 'dc_user' => '',
							 				 'dc_data_modif' => '',
							 				 'dc_category' => '',
							 				 'dc_lang' => '',
							 				 'dc_infotelnome1' => '',
							 				 'dc_infotelnome2' => '',
							 				 'dc_approved' => '',
											 'dc_submitter' => '');
}

/**
 * utility function to check the fields validity
 *
 * @return boolean true on check passed, false on error 
 */
function concert_adminapi_validate ($item){
		//Now we check for dc_paese : it has to be filled!
		if ($item['dc_paese']=='') {
				pnSessionSetVar('errormsg', _CITY_ERROR);
				return false;
		}
/*
		 we check also for correct email address, but only if one is given
		if (isset($item['dc_infomailaddr1'])){
			  print $item['dc_infomailaddr1'];
			 if (!pnVarValidate($item['dc_infomailaddr1'], email)) {
				pnSessionSetVar('errormsg', _EMAIL_ERROR);
      	pnRedirect(pnModURL('concert', 'admin', 'correct', $item));
				return true;
			}
		
		}

		 validate url
		if(!pnVarValidate(http://www.example.com,url)) {
			die(URL is invalid);
		}
*/
	 return true;
}
?>
