<?php
// $Id: pnuserapi.php,v 1.10 2002/10/10 10:37:12 garubi Exp $
// ----------------------------------------------------------------------
// POST-NUKE Content Management System
// Copyright (C) 2001 by the PostNuke Development Team.
// http://www.postnuke.com/
// ----------------------------------------------------------------------
// Based on:
// PHP-NUKE Web Portal System - http://phpnuke.org/
// Thatware - http://thatware.org/
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
// Original Author of file: Stefano Garuti
// Purpose of file:  Concert user API
// ----------------------------------------------------------------------

/**
 * get concert items
 * 
 * @param $args['startnum'] first item number (for pager function)
 * @param $args['numitems'] how many items (for pager function)
 * @param $args['what'] which concert to retrieve: 'allconc' or 'nextconc'
 * @see concert_userapi_setwhere() for more info on allconc|nextconc
 * @return array of items, or false on failure
 */
function concert_userapi_getall($args)
{
    //
    extract($args);

    // Optional arguments.
    if (!isset($startnum)) {
        $startnum = 1;
    }
    if (!isset($numitems)) {
        $numitems = -1;
    }
	
    if ((!isset($startnum)) ||
        (!isset($numitems))) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }
		
	$items = array();

    // Security check
    if (!pnSecAuthAction(0, 'concert::', '::', ACCESS_OVERVIEW)) {
        return $items;
    }

    // Database information
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

	// Set Where clause
	$where=	pnModAPIFunc('concert', 'user', 'setwhere', array('what'=>$what));

	// Set order by
	// $orderby= pnModAPIFunc('concert', 'user', 'orderby', array('ordfield'=>$ordfield, 'ord'=>$ord));
	
	// Get items
    $sql = 	"SELECT * FROM $concerttable".$where." ORDER BY $concertcolumn[dc_data]";
		
		//$dbconn->debug=true;
		//echo "<pre>";
    $result = $dbconn->Execute($sql);
		//echo "</pre>";
	
	
    if ($dbconn->ErrorNo() != 0) {
        return false;
    }

    // Put items into result array
    for (; !$result->EOF; $result->MoveNext()) {
        list(	$dc_id,
				$dc_paese,
				$dc_prov,
				$dc_stato,
				$dc_locale,
				$dc_note,
				$dc_infomailnome1,
				$dc_infomailaddr1,
				$dc_infotel1,
				$dc_infotel2,
				$dc_url_locale,
				$dc_indirizzo_locale,
				$dc_n_comm,
				$dc_data,
				$dc_conf,
				$dc_user,
				$dc_data_modif,
				$dc_category,
				$dc_lang,
				$dc_infotelnome1,
				$dc_infotelnome2,
				$dc_approved,
				$dc_submitter
			) = $result->fields;

        if (pnSecAuthAction(0, 'concert::', ":$dc_category:$dc_id", ACCESS_OVERVIEW)) {
            $items[] = array('dc_id' => $dc_id,
							 'dc_paese' => $dc_paese,
							 'dc_prov' => $dc_prov,
							 'dc_stato' => $dc_stato,
							 'dc_locale' => $dc_locale,
							 'dc_note' => $dc_note,
							 'dc_infomailnome1' => $dc_infomailnome1,
							 'dc_infomailaddr1' => $dc_infomailaddr1,
							 'dc_infotel1' => $dc_infotel1,
							 'dc_infotel2' => $dc_infotel2,
							 'dc_url_locale' => $dc_url_locale,
							 'dc_indirizzo_locale' => $dc_indirizzo_locale,
							 'dc_n_comm' => $dc_n_comm,
							 'dc_data' => $dc_data,
							 'dc_conf' => $dc_conf,
							 'dc_user' => $dc_user,
							 'dc_data_modif' => $dc_data_modif,
							 'dc_category' => $dc_category,
							 'dc_lang' => $dc_lang,
							 'dc_infotelnome1' => $dc_infotelnome1,
							 'dc_infotelnome2' => $dc_infotelnome2,
							 'dc_approved'		 => $dc_approved,
							 'dc_submitter'		 =>	$dc_submitter);
        }
    }
    $result->Close();

		// we can't use SelectLimit because we need to consider the Category!
		// so we slice here the result array to do the paging 
		$sliced=array_slice($items,$startnum-1,$numitems);
		return $sliced;
}

/**
 * get a specific concert
 *
 * this function isn't yet implemented 
 *
 * @param $args['dc_id'] id of concert item to get
 * @returns array
 * @return item array, or false on failure
 */
function concert_userapi_get($args)
{
    // Get arguments from argument array
    extract($args);

    // Argument check
    if (!isset($dc_id)) {
        pnSessionSetVar('errormsg', _MODARGSERROR);
        return false;
    }

    // Get datbase setup
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

    // Get item
    $sql = "SELECT *
            FROM $concerttable
            WHERE $concertcolumn[dc_id] = " . pnVarPrepForStore($dc_id);

    $result = $dbconn->Execute($sql);

    if ($dbconn->ErrorNo() != 0) {
        return false;
    }

    if ($result->EOF) {
        return false;
    }

    list(	$dc_id,
				$dc_paese,
				$dc_prov,
				$dc_stato,
				$dc_locale,
				$dc_note,
				$dc_infomailnome1,
				$dc_infomailaddr1,
				$dc_infotel1,
				$dc_infotel2,
				$dc_url_locale,
				$dc_indirizzo_locale,
				$dc_n_comm,
				$dc_data,
				$dc_conf,
				$dc_user,
				$dc_data_modif,
				$dc_category,
				$dc_lang,
				$dc_infotelnome1,
				$dc_infotelnome2,
				$dc_approved,
				$dc_submitter
			) = $result->fields;

    // Security check
    if (!pnSecAuthAction(0, 'concert::', ":$dc_category:$dc_id", ACCESS_READ)) {
        return false;
    }

            $item = array('dc_id' => $dc_id,
							 'dc_paese' => $dc_paese,
							 'dc_prov' => $dc_prov,
							 'dc_stato' => $dc_stato,
							 'dc_locale' => $dc_locale,
							 'dc_note' => $dc_note,
							 'dc_infomailnome1' => $dc_infomailnome1,
							 'dc_infomailaddr1' => $dc_infomailaddr1,
							 'dc_infotel1' => $dc_infotel1,
							 'dc_infotel2' => $dc_infotel2,
							 'dc_url_locale' => $dc_url_locale,
							 'dc_indirizzo_locale' => $dc_indirizzo_locale,
							 'dc_n_comm' => $dc_n_comm,
							 'dc_data' => $dc_data,
							 'dc_conf' => $dc_conf,
							 'dc_user' => $dc_user,
							 'dc_data_modif' => $dc_data_modif,
							 'dc_category' => $dc_category,
							 'dc_lang' => $dc_lang,
							 'dc_infotelnome1' => $dc_infotelnome1,
							 'dc_infotelnome2' => $dc_infotelnome2,
							 'dc_approved'=>$dc_approved,
							 'dc_submitter'		=> $dc_submitter);

		// prevent who has not the ADD access to retrieve pending concerts
    if (($dc_approved==0) and (!pnSecAuthAction(0, 'concert::', ":$dc_category:$dc_id", ACCESS_ADD))) {
        return false;
    }
							 
    return $item;
}


/**
 * count concert items 
 *
 * utility function to count the number of concert stored by this module
 * It count only concerts visibles according to permission settings and where clause
 * @return number of items held by this module
 * @param $what string one of 'nextconc' or 'allconc'
 */
function concert_userapi_countitems($what)
{
    // Get database setup - note that both pnDBGetConn() and pnDBGetTables()
    // return arrays but we handle them differently.  For pnDBGetConn() we
    // currently just want the first item, which is the official database
    // handle.  For pnDBGetTables() we want to keep the entire tables array
    // together for easy reference later on
    list($dbconn) = pnDBGetConn();
    $pntable = pnDBGetTables();

    // It's good practice to name the table and column definitions you are
    // getting - $table and $column don't cut it in more complex modules
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

	// Set Where clause
	$where=	pnModAPIFunc('concert', 'user', 'setwhere', array('what'=>$what));

    // Get item - the formatting here is not mandatory, but it does make the
    // SQL statement relatively easy to read.  Also, separating out the sql
    // statement from the Execute() command allows for simpler debug operation
    // if it is ever needed

		$sql = "SELECT * FROM $concerttable".$where;
		$result = $dbconn->Execute($sql);

		
    // Check for an error with the database code, and if so set an appropriate
    // error message and return
    if ($dbconn->ErrorNo() != 0) {
        return false;
    }

		$numitems=0;
		for (; !$result->EOF; $result->MoveNext()) {

				$row = $result->GetRowAssoc(false);

			  if (pnSecAuthAction(0, 'concert::', ":$row[dc_category]:$row[dc_id]", ACCESS_OVERVIEW)) {
					$numitems++;
				}
		}
    // All successful database queries produce a result set, and that result
    // set should be closed when it has been finished with
    $result->Close();

    // Return the number of items
    return $numitems;
}
/**
 * Set WHERE condition
 *
 * utility function to setting up proper sql WHERE conditions
 *
 * @param $what string one of 'nextconc' and 'allconc'; nextconc is the default
 * @return string the where clause to be inserted in SQL statement
 * @private
 */
function concert_userapi_setwhere($what='nextconc')
{
    extract($what);
	
	$pntable = pnDBGetTables();
    $concerttable = $pntable['conc'];
    $concertcolumn = &$pntable['conc_column'];

	switch ($what) {
		case 'allconc' :
			$where=' WHERE ';	
		break;
		default :
			// the default is set up to show next concerts
			$where= ' WHERE TO_DAYS('.$concertcolumn['dc_data'].')>=TO_DAYS(NOW()) AND ';
	}
	
	// also we filter out all the non-approved concerts
	$where.= $concertcolumn['dc_approved']."='1'";
	return $where;
}


?>
